==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/merchant/MerchantQueryDepartmentInfoResBean.java <==
package global.hh.openapi.sdk.api.bean.merchant;


/**
 * @description: 根据门店查询大区办事处信息
 * @author: 3742
 * @date: 2018-15-12 13:15:04
 */
public class MerchantQueryDepartmentInfoResBean {

        /**
         * 大区编号
         */
        private String areaCode;

        /**
         * 大区名称
         */
        private String areaName;

        /**
         * 办事处编号
         */
        private String officeCode;

        /**
         * 办事处名称
         */
        private String officeName;

        /**
         * 门店编号
         */
        private String terminalCode;

        /**
         * 门店名称
         */
        private String terminalName;

    public MerchantQueryDepartmentInfoResBean(){
    }

    public MerchantQueryDepartmentInfoResBean(String areaCode,String areaName,String officeCode,String officeName,String terminalCode,String terminalName){
        this.areaCode=areaCode;
        this.areaName=areaName;
        this.officeCode=officeCode;
        this.officeName=officeName;
        this.terminalCode=terminalCode;
        this.terminalName=terminalName;
    }

    private String getAreaCode() {
        return areaCode;
    }

    private void setAreaCode(String areaCode) {
        this.areaCode = areaCode;
    }
    private String getAreaName() {
        return areaName;
    }

    private void setAreaName(String areaName) {
        this.areaName = areaName;
    }
    private String getOfficeCode() {
        return officeCode;
    }

    private void setOfficeCode(String officeCode) {
        this.officeCode = officeCode;
    }
    private String getOfficeName() {
        return officeName;
    }

    private void setOfficeName(String officeName) {
        this.officeName = officeName;
    }
    private String getTerminalCode() {
        return terminalCode;
    }

    private void setTerminalCode(String terminalCode) {
        this.terminalCode = terminalCode;
    }
    private String getTerminalName() {
        return terminalName;
    }

    private void setTerminalName(String terminalName) {
        this.terminalName = terminalName;
    }
}

==> biostime-openapi-sdk-1.5.9.1-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/merchant/MerchantQueryDepartmentInfoResBean.java <==
package global.hh.openapi.sdk.api.bean.merchant;


/**
 * @description: 根据门店查询大区办事处信息
 * @author: 3742
 * @date: 2018-43-07 13:43:49
 */
public class MerchantQueryDepartmentInfoResBean {

        /**
         * 大区编号
         */
        private String areaCode;

        /**
         * 大区名称
         */
        private String areaName;

        /**
         * 办事处编号
         */
        private String officeCode;

        /**
         * 办事处名称
         */
        private String officeName;

        /**
         * 门店编号
         */
        private String terminalCode;

        /**
         * 门店名称
         */
        private String terminalName;

    public MerchantQueryDepartmentInfoResBean(){
    }

    public MerchantQueryDepartmentInfoResBean(String areaCode,String areaName,String officeCode,String officeName,String terminalCode,String terminalName){
        this.areaCode=areaCode;
        this.areaName=areaName;
        this.officeCode=officeCode;
        this.officeName=officeName;
        this.terminalCode=terminalCode;
        this.terminalName=terminalName;
    }

    public String getAreaCode() {
        return areaCode;
    }

    public void setAreaCode(String areaCode) {
        this.areaCode = areaCode;
    }
    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }
    public String getOfficeCode() {
        return officeCode;
    }

    public void setOfficeCode(String officeCode) {
        this.officeCode = officeCode;
    }
    public String getOfficeName() {
        return officeName;
    }

    public void setOfficeName(String officeName) {
        this.officeName = officeName;
    }
    public String getTerminalCode() {
        return terminalCode;
    }

    public void setTerminalCode(String terminalCode) {
        this.terminalCode = terminalCode;
    }
    public String getTerminalName() {
        return terminalName;
    }

    public void setTerminalName(String terminalName) {
        this.terminalName = terminalName;
    }
}
